==> kdegraphics_3.3.2.orig.tar.gz: kdegraphics-3.3.2/ksvg/dom/SVGFontFaceUriElement.h <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef SVGFontFaceUriElement_H
#define SVGFontFaceUriElement_H

#include "SVGElement.h"

namespace KSVG
{

class SVGFontFaceUriElementImpl;
class SVGFontFaceUriElement : public SVGElement
{
public:
	SVGFontFaceUriElement();
	SVGFontFaceUriElement(const SVGFontFaceUriElement &other);
	SVGFontFaceUriElement &operator=(const SVGFontFaceUriElement &other);
	SVGFontFaceUriElement(SVGFontFaceUriElementImpl *other);
	virtual ~SVGFontFaceUriElement();

	// Internal! - NOT PART OF THE SVG SPECIFICATION
	SVGFontFaceUriElementImpl *handle() const { return impl; }

private:
	SVGFontFaceUriElementImpl *impl;
};

};

#endif

// vim:ts=4:noet

==> kdegraphics_3.5.9.orig.tar.gz: kdegraphics-3.5.9/ksvg/dom/SVGFontFaceUriElement.h <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef SVGFontFaceUriElement_H
#define SVGFontFaceUriElement_H

#include "SVGElement.h"

namespace KSVG
{

class SVGFontFaceUriElementImpl;
class SVGFontFaceUriElement : public SVGElement
{
public:
	SVGFontFaceUriElement();
	SVGFontFaceUriElement(const SVGFontFaceUriElement &other);
	SVGFontFaceUriElement &operator=(const SVGFontFaceUriElement &other);
	SVGFontFaceUriElement(SVGFontFaceUriElementImpl *other);
	virtual ~SVGFontFaceUriElement();

	// Internal! - NOT PART OF THE SVG SPECIFICATION
	SVGFontFaceUriElementImpl *handle() const { return impl; }

private:
	SVGFontFaceUriElementImpl *impl;
};

}

#endif

// vim:ts=4:noet
